@@ -209,7 +209,16 @@ def find_corrupt_pkgs(vdb_path, deep=True, verbose=True):
             file_exec = subprocess.run(
                 ["file", "-b", installed_path], stdout=subprocess.PIPE
             )
-            file_exec_result = file_exec.stdout.decode("utf-8")
+
+            try:
+                file_exec_result = file_exec.stdout.decode("utf-8")
+            except UnicodeDecodeError:
+                # It should be reasonable to skip in situations like this as it's clearly
+                # not going to be a dynamically linked ELF like we're expecting.
+                # https://github.com/thesamesam/recover-broken-vdb/issues/6
+                print(
+                    "Hit a UnicodeDecodeError on {0}, skipping.".format(installed_path)
+                )
 
             if (
                 "ELF" not in file_exec_result
@@ -361,6 +370,11 @@ def find_corrupt_pkgs(vdb_path, deep=True, verbose=True):
     return broken_packages, unexpected_case_found
 
 
+def chunk_list(lst, n):
+    for i in range(0, len(lst), n):
+        yield lst[i : i + n]
+
+
 def fix_vdb(vdb_path, filesystem, package, verbose=True):
     """
     Creates PROVIDES, REQUIRES, NEEDED, and NEEDED.ELF.2 for a package in
@@ -383,9 +397,8 @@ def fix_vdb(vdb_path, filesystem, package, verbose=True):
     with tempfile.TemporaryDirectory() as tmpdir:
         tmpdir_path = pathlib.Path(tmpdir)
 
-        contents = " ".join(package.dyn_paths)
-
-        subprocess.run(["recover-broken-vdb-scanelf.sh", tmpdir, contents])
+        for chunk in chunk_list(package.dyn_paths, 1000):
+            subprocess.run(["recover-broken-vdb-scanelf.sh", tmpdir] + chunk)
 
         if not (tmpdir_path / "build-info" / "NEEDED").exists():
             # Not an interesting binary.
